%define pypi_name	sphinx-rtd-theme
%define srcname		sphinx_rtd_theme

%bcond_with check
%bcond_with doc

Name:		python-%{pypi_name}
Version:	3.0.2
Release:	%mkrel 2
Summary:	Sphinx theme for readthedocs.org
Group:		Development/Python
License:	MIT
URL:		https://pypi.org/project/sphinx-rtd-theme/
Source0:	https://github.com/readthedocs/sphinx_rtd_theme/archive/%{version}/%{srcname}-%{version}.tar.gz
# build host do not have network access, and this file is not included
# in any Magiea package, so we retrieve it for offline use.
Source1:	https://docs.readthedocs.io/en/latest/objects.inv
# Unbundle fonts.  Refer to local fonts instead.
Patch1:		python-sphinx_rtd_theme-unbundle-fonts.patch
BuildArch:	noarch
BuildRequires:  python3-devel
%if %{with check}
BuildRequires:	python3dist(pytest)
%endif
%if %{with doc}
BuildRequires:	python3dist(readthedocs-sphinx-ext)
BuildRequires:	python3dist(sphinx)
BuildRequires:	python3dist(sphinxcontrib-httpdomain)
%endif

%description
This is a prototype mobile-friendly sphinx theme for readthedocs.org.
It's currently in development and includes some rtd variable checks that
can be ignored if you're just trying to use it on your project outside
of that site.

%package -n	python3-%{pypi_name}
Summary:	%{summary}
Group:		Development/Python
%{?python_provide:%python_provide python3-%{pypi_name}}
%{?python_provide:%python_provide python3-%{srcname}}
%{?py_provides:%py_provides python3-%{srcname}}
Obsoletes:	python3-sphinx_rtd_theme < 1.0.0-4

%description -n	python3-%{pypi_name}
This is a prototype mobile-friendly sphinx theme for readthedocs.org.
It's currently in development and includes some rtd variable checks that
can be ignored if you're just trying to use it on your project outside
of that site.

%package doc
Summary:	Documentation for the Sphinx theme for readthedocs.org
Group:		Development/Python

%description doc
This package contains documentation for the Sphinx theme for
readthedocs.org.

%prep
%autosetup -p1 -n %{srcname}-%{version}

# loosen docutils reqs
sed -i -e 's/docutils</docutils>/g' setup.py

# Use local objects.inv for intersphinx
sed -e "s|\('https://docs\.readthedocs\.io/en/stable/', \)None|\1'%{SOURCE1}'|" \
    -e "s|\('https://www\.sphinx-doc\.org/en/master/', \)None|\1'%{_docdir}/python-sphinx-doc/html/objects.inv'|" \
    -i docs/conf.py

# We cannot build the Javascript from source at this time, due to many missing
# dependencies.  Convince the build script to skip building the Javascript and
# go on to the python.
mkdir -p build/lib/%{pypi_name}/static/js
cp -p sphinx_rtd_theme/static/js/badge_only.js build/lib/%{pypi_name}/static/js
cp -p sphinx_rtd_theme/static/js/theme.js build/lib/%{pypi_name}/static/js
sed -i "/'build_py'/d" setup.py

%build
%pyproject_wheel

%if %{with doc}
# Build the documentation
make -C docs html
rm docs/build/html/.buildinfo
rst2html --no-datestamp README.rst README.html
%endif

%install
%pyproject_install
%pyproject_save_files %{pypi_name} sphinx_rtd_theme

# Unbundle fonts
rm -fr %{buildroot}%{python3_sitelib}/%{pypi_name}/static/css/fonts

%if %{with check}
%check
pytest
%endif

%files -n python3-%{pypi_name} -f %{pyproject_files}
%license LICENSE
%doc README.rst
%if %{with doc}
%doc docs/build/html
%endif


%changelog
* Wed Jul 02 2025 umeabot <umeabot> 3.0.2-2.mga10
+ Revision: 2236209
- Mageia 10 Mass Rebuild

* Fri Feb 21 2025 wally <wally> 3.0.2-1.mga10
+ Revision: 2150554
- new version 3.0.2
- rebuild for python3.13

* Thu Dec 07 2023 wally <wally> 1.0.0-6.mga10
+ Revision: 2014980
- rebuild for py3.12

* Tue Sep 06 2022 neoclust <neoclust> 1.0.0-5.mga9
+ Revision: 1884542
- Migrate using pyproject to build

* Mon Aug 29 2022 wally <wally> 1.0.0-4.mga9
+ Revision: 1881707
- rename src.rpm as python-sphinx-rtd-theme

* Wed Mar 23 2022 umeabot <umeabot> 1.0.0-3.mga9
+ Revision: 1823231
- Mageia 9 Mass Rebuild

* Sun Feb 20 2022 tv <tv> 1.0.0-2.mga9
+ Revision: 1781962
- Rebuild for downgraded docutils

* Sun Feb 06 2022 wally <wally> 1.0.0-1.mga9
+ Revision: 1772089
- new version 1.0.0
- rebuild for python3.10
- allow installing with docutils >= 0.18.1

* Wed Apr 07 2021 daviddavid <daviddavid> 0.5.2-1.mga9
+ Revision: 1713956
- new version: 0.5.2

* Sun Mar 14 2021 wally <wally> 0.5.1-2.mga9
+ Revision: 1702707
- rebuild for python 3.9
- drop doc pkg
- bootstrap for sphinx build

* Tue Mar 02 2021 guillomovitch <guillomovitch> 0.5.1-1.mga9
+ Revision: 1696400
- new version 0.5.1

* Sun Feb 16 2020 umeabot <umeabot> 0.4.3-4.mga8
+ Revision: 1530940
- Mageia 8 Mass Rebuild

* Fri Sep 06 2019 wally <wally> 0.4.3-3.mga8
+ Revision: 1437882
- rebuild for python3.8

* Sun Aug 04 2019 wally <wally> 0.4.3-2.mga8
+ Revision: 1427259
- drop python2 support

* Fri Feb 15 2019 daviddavid <daviddavid> 0.4.3-1.mga7
+ Revision: 1367148
- new version: 0.4.3

* Sat Jan 05 2019 wally <wally> 0.4.2-2.mga7
+ Revision: 1349680
- rebuild for python3.7

* Wed Oct 10 2018 daviddavid <daviddavid> 0.4.2-1.mga7
+ Revision: 1319190
- new version: 0.4.2

* Thu Sep 20 2018 umeabot <umeabot> 0.4.1-2.mga7
+ Revision: 1290203
- Mageia 7 Mass Rebuild

* Sat Jul 28 2018 daviddavid <daviddavid> 0.4.1-1.mga7
+ Revision: 1245691
- new version: 0.4.1

* Mon Jun 11 2018 daviddavid <daviddavid> 0.4.0-1.mga7
+ Revision: 1236243
- new version: 0.4.0

* Thu May 03 2018 daviddavid <daviddavid> 0.3.1-1.mga7
+ Revision: 1225477
- new version: 0.3.1

* Mon Apr 16 2018 kekepower <kekepower> 0.3.0-2.mga7
+ Revision: 1219201
- Create and use py3dir
- Use python_provide

* Sat Apr 07 2018 daviddavid <daviddavid> 0.3.0-1.mga7
+ Revision: 1215851
- new version: 0.3.0

* Sun Aug 27 2017 daviddavid <daviddavid> 0.2.4-1.mga7
+ Revision: 1148270
- new version: 0.2.4
- rename python-sphinx_rtd_theme to python2-sphinx_rtd_theme

* Thu Aug 03 2017 tv <tv> 0.1.9-3.mga7
+ Revision: 1134482
- rebuild for new python
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild

* Wed Nov 25 2015 daviddavid <daviddavid> 0.1.9-1.mga6
+ Revision: 905886
- new version: 0.1.9

* Wed Oct 07 2015 daviddavid <daviddavid> 0.1.8-2.mga6
+ Revision: 886869
- rebuild for python 3.5
- use new python macros

* Thu Jul 16 2015 daviddavid <daviddavid> 0.1.8-1.mga6
+ Revision: 854595
- imported package python-sphinx_rtd_theme (based on Fedora)

